package de.intevation.gnv.state;

import java.io.Serializable;

/**
 * This interface defines some basic methods to retrieve information about the
 * type of an user input.
 * 
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface InputValue extends Serializable {

    /**
     * Retrieve the name of the inserted data.
     *
     * @return the input data name.
     */
    public String getName();

    /**
     * Retrieve the type of the input.
     *
     * @return the input data type.
     */
    public String getType();

    /**
     * Retrieve the default value used when no input is done.
     *
     * @return the input data default value.
     */
    public String getDefaultValue();

    /**
     * Retrieve information about mutliselect fields.
     *
     * @return true, if the input data is a multiselect, otherwise false.
     */
    public boolean isMultiselect();

    /**
     * Retrieve information about the occurance of this input in an sql
     * statement.
     *
     * @return the number of times, this data is used in a sql query.
     */
    public int usedInQueries();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
